Crate deepstore_server_client

Crate deepstore_server_client 

Generated client for deepstore-server control plane API. Code is produced at build time by progenitor into $OUT_DIR/codegen.rs.

Modules

builder
Types for composing operation parameters.
prelude
Items consumers will typically use such as the Client.
types
Types used as operation parameters and responses.

Structs

ByteStream
Untyped byte stream used for both success and error responses.
Client
Client for DeepStore API
ResponseValue
Typed value returned by generated client methods.

Enums

Error
Error produced by generated client methods.

Traits

ClientInfo
Interface for which an implementation is generated for all clients.